sagenb_export: Convert legacy SageNB notebooks to Jupyter notebooks and other formats
=====================================================================================

Description
-----------

This is a tool to convert SageNB notebooks to other formats, in
particular IPython/Jupyter notebooks.

It includes a Jupyter notebook extension to provide a UI for the import
of SageNB notebooks.

Upstream Contact
----------------

https://github.com/vbraun/ExportSageNB
